@@ -6,7 +6,7 @@ use log::{self, error};
 use simple_logger;
 
 fn main() -> Result<(), Box<dyn Error>> {
-    simple_logger::init_with_level(log::Level::Debug).unwrap();
+    simple_logger::init_with_level(log::Level::Debug)?;
     lambda!(my_handler);
 
     Ok(())
